import React, { useContext } from 'react';
import { useLocation, matchPath } from 'react-router-dom';
import { GamesContext } from '../../context/games';

import { Color, Player, Board } from '../../components/Checkers';
import './GameBoard.css';

export default function GameBoard() {
  const games = useContext(GamesContext);
  const { pathname } = useLocation();

  const [opponentName, opponentColor, myColor] = (() => {
    if (matchPath('/games/new', pathname))
      return [games.newGame.opponentName, games.newGame.opponentColor, Color.opposite(games.newGame.opponentColor)];

    let selectedGame;

    if (matchPath('/games/proposal', pathname))
      selectedGame = games.findGame({ uuid: games.proposal.selectedUUID });
    else if (matchPath('/games/active', pathname))
      selectedGame = games.findGame({ uuid: games.active.selectedUUID });
    else if (matchPath('/games/archive', pathname))
      selectedGame = games.findGame({ uuid: games.archive.selectedUUID });

    if (selectedGame)
      return [selectedGame?.opponentName, Color.opposite(selectedGame?.myColor), selectedGame?.myColor];
    else
      return ['', Color.white, Color.black]; //  defaults
  })(); // <<-- Execute

  return (
    <div className='GameBoard'>
      <Player color={opponentColor} name={opponentName} />
      <Board />
      <Player color={myColor} name={opponentName ? 'MyName' : ''} />
    </div>
  )
}